//
//  SecurityLevelController.m
//  AsReaderScan
//
//  Created by Mikiko on 11/7/24.
//  Copyright © 2024 SPS INC. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "SecurityLevelController.h"

@interface SecurityLevelController ()

@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) UIButton *okButton;
@property (nonatomic, strong) UIButton *cancelButton;

@end

@implementation SecurityLevelController

- (instancetype)init {
    self = [super init];
    if (self) {
        _model = Store.shared;
        _selectLevel = @[@"Level0", @"Level1", @"Level2", @"Level3"];
    }
    return self;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    [self setupUI];
}

- (void)setupUI {
    self.view.backgroundColor = [UIColor whiteColor];
    
    self.tableView = [[UITableView alloc] init];
    self.tableView.translatesAutoresizingMaskIntoConstraints = NO;
    self.tableView.dataSource = self;
    self.tableView.delegate = self;
    [self.tableView registerClass:[UITableViewCell class] forCellReuseIdentifier:@"OptionCell"];
    
    self.okButton = [UIButton buttonWithType:UIButtonTypeSystem];
    [self.okButton setTitle:@"Save" forState:UIControlStateNormal];
    [self.okButton addTarget:self action:@selector(okButtonTapped) forControlEvents:UIControlEventTouchUpInside];
    self.okButton.translatesAutoresizingMaskIntoConstraints = NO;
    
    self.cancelButton = [UIButton buttonWithType:UIButtonTypeSystem];
    [self.cancelButton setTitle:@"Cancel" forState:UIControlStateNormal];
    [self.cancelButton addTarget:self action:@selector(cancelButtonTapped) forControlEvents:UIControlEventTouchUpInside];
    self.cancelButton.translatesAutoresizingMaskIntoConstraints = NO;
    
    [self.view addSubview:self.tableView];
    [self.view addSubview:self.okButton];
    [self.view addSubview:self.cancelButton];
    
    [NSLayoutConstraint activateConstraints:@[
        [self.tableView.topAnchor constraintEqualToAnchor:self.view.topAnchor constant:20],
        [self.tableView.leadingAnchor constraintEqualToAnchor:self.view.leadingAnchor constant:20],
        [self.tableView.trailingAnchor constraintEqualToAnchor:self.view.trailingAnchor constant:-20],
        [self.tableView.heightAnchor constraintEqualToConstant:500],

        [self.okButton.topAnchor constraintEqualToAnchor:self.tableView.bottomAnchor constant:20],
        [self.okButton.leadingAnchor constraintEqualToAnchor:self.view.leadingAnchor constant:20],
        [self.okButton.trailingAnchor constraintEqualToAnchor:self.view.trailingAnchor constant:-20],
        [self.okButton.heightAnchor constraintEqualToConstant:40],

        [self.cancelButton.topAnchor constraintEqualToAnchor:self.okButton.bottomAnchor constant:10],
        [self.cancelButton.leadingAnchor constraintEqualToAnchor:self.view.leadingAnchor constant:20],
        [self.cancelButton.trailingAnchor constraintEqualToAnchor:self.view.trailingAnchor constant:-20],
        [self.cancelButton.heightAnchor constraintEqualToConstant:40]
    ]];
}

- (void)okButtonTapped {
    [self.delegate updateSecurity];
    [self dismissViewControllerAnimated:YES completion:nil];
}

- (void)cancelButtonTapped {
    [self dismissViewControllerAnimated:YES completion:nil];
}

#pragma mark - UITableViewDataSource

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.model.securityTableFromArray.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"OptionCell" forIndexPath:indexPath];
    SecurityItemFromArray *optionItem = self.model.securityTableFromArray[indexPath.row];
    cell.textLabel.text = optionItem.title;

    UIButton *button = [UIButton buttonWithType:UIButtonTypeSystem];
    [button setTitle:[self getSelectedLevel:optionItem.level] forState:UIControlStateNormal];
    button.frame = CGRectMake(0, 0, 80, 30);
    [button addTarget:self action:@selector(dropdownButtonTapped:) forControlEvents:UIControlEventTouchUpInside];
    button.tag = indexPath.row;
    cell.accessoryView = button;

    return cell;
}

- (void)dropdownButtonTapped:(UIButton *)sender {
    NSString *selectedOption = self.model.securityTableFromArray[sender.tag].title;

    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:selectedOption message:nil preferredStyle:UIAlertControllerStyleActionSheet];

    for (NSString *level in self.selectLevel) {
        UIAlertAction *action = [UIAlertAction actionWithTitle:level style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
            NSInteger levelInt = [self.selectLevel indexOfObject:level];
            [self.model setSecurityLevel:selectedOption level:levelInt];
            self.model.securityTableFromArray = self.model.securityTableFromArray; // Refresh data
            [self.tableView reloadData];
        }];
        [alertController addAction:action];
    }

    UIAlertAction *cancelAction = [UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:nil];
    [alertController addAction:cancelAction];

    if (alertController.popoverPresentationController) {
        alertController.popoverPresentationController.sourceView = sender;
        alertController.popoverPresentationController.sourceRect = sender.bounds;
    }

    [self presentViewController:alertController animated:YES completion:nil];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    [tableView reloadRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationAutomatic];
}

- (NSString *)getSelectedLevel:(NSInteger)option {
    return self.selectLevel[option];
}

@end
