//
//  SettingPresenter.h
//  AsReaderScan
//
//  Created by Mikiko on 11/7/24.
//  Copyright © 2024 SPS INC. All rights reserved.
//

#ifndef SettingPresenter_h
#define SettingPresenter_h


#endif /* SettingPresenter_h */
// SettingPresenter.h
#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import <AsReaderDockSDK/AsReaderDockSDK.h>
#import "Store.h"
#import "AutoLaunchController.h"

@protocol SettingPresenterDelegate <NSObject>
- (void)updatedReaderInfo;
@end

/**
 *  @brief      This is for M24D. This file is part of a larger application that interacts with settings related to a barcode reader device (M24D), including symbology and other configuration options. It appears to be responsible for managing the application's settings interface and coordinating between the model (which stores the settings data) and the view/controller (which presents and interacts with the UI).
 */
@interface SettingPresenter : NSObject

@property (nonatomic, weak) id<SettingPresenterDelegate> delegate;
@property (nonatomic, strong) AsReaderBarcodeDevice *barcode;
@property (nonatomic, strong) UINavigationController *navigationController;
@property (nonatomic, strong) UIViewController *viewController;
@property (nonatomic, strong) AutoLaunchController *autoLaunchController;
@property (nonatomic, strong) Store *model;
//@property (nonatomic, strong) AutoLaunchController *autoLaunchController;

//- (instancetype)initWithDelegate:(id<SettingPresenterDelegate>)delegate;
+ (instancetype)sharedInstance;
- (void)setDelegate:(id<SettingPresenterDelegate>)delegate;
// Symbology methods
- (void)setAllSymbolEnable;
- (void)setAllSymbolDisable;
- (void)setSymbolEnable:(NSString *)name isEnable:(BOOL)isEnable;
- (void)updateSymbology;
- (void)updateSecurity;

- (void)receivedCodeID:(int32_t)codeID;
- (void)receivedSleepTime:(int32_t)time;
- (void)receivedHID:(BOOL)hidOn receivediOSHID:(BOOL)iOShidOn;
- (void)receivedPresentationMode:(BOOL)isOn;
- (void)receivedSleepBeep:(NSData *)data;
- (void)receivedOCR:(BOOL)isNone ocrAon:(BOOL)isOCRAon ocrBOn:(BOOL)isOCRBon;
- (void)receivedBarcodeSecurity:(NSDictionary<NSString *, id> *)security;
- (void)receivedGetAutoLaunch:(BOOL)isOn bundle:(NSString *)data;

- (void)settingReceivedCodeID:(NSString *)value;
- (void)settingReceivedSleepTime:(NSString *)value;
- (void)settingReceivedHID:(BOOL)hidOn receivediOSHID:(BOOL)iOShidOn;
- (void)settingReceivedPresentationMode:(BOOL)isOn;
- (void)settingReceivedSleepBeep:(NSData *)data;
- (void)settingReceivedOCR:(NSInteger)value;
- (void)didSelectOptions:(NSSet<NSString *> *)options;
- (void)settingReceivedBarcodeSecurity;
- (void)settingReceivedGetAutoLaunch:(BOOL)isOn bundle:(NSString *)bundle;
- (void)settingReceivedSetAutoLaunch:(BOOL)isOn bundle:(NSString *)bundle;
- (void)settingReceivedAutoLaunch:(NSData *)data;

- (void)setCodeID:(CodeID)type;
- (void)setSleepTime:(NSInteger)time;
- (void)setEnableAndroidHID:(BOOL)isOn;
- (void)setEnableiOSHID:(BOOL)isOn;
- (void)setPresentationMode:(BOOL)isOn;
- (void)setSleepBeep:(BOOL)isOn;
- (void)setOCRType:(TypeOCR)type;
- (void)setSsiParam:(NSDictionary<NSNumber *, BarcodeZebraSsiParam *> *)dict;
- (void)setAutoLaunch:(BOOL)isOn bundle:(NSString *)bundle;


- (void)getHIDMode;
- (void)getPresentationMode;
- (void)getSymbology;
- (void)getSecurity;
- (void)getAutoLaunch;
- (void)changeSwitch:(BOOL)isOn tagID:(NSInteger)tagID;
- (void)handleHIDSettings:(BOOL)hidOn receivediOSHID:(BOOL)iOShidOn forIDs:(IDs)ids;
- (void)btnEvent:(NSInteger)tagID viewController:(UIViewController *)vc;

@end
