//
//  SymbologyViewController.m
//  AsReaderScan
//
//  Created by Mikiko on 11/7/24.
//  Copyright © 2024 SPS INC. All rights reserved.
//

#import "SymbologyViewController.h"
#import "SettingPresenter.h"
#import "SymbologyTableViewCell.h"
#import "ParamModel.h"

@interface SymbologyViewController() <SettingPresenterDelegate>
@end

@implementation SymbologyViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [self initialDelegate];
    self.title = @"Symbology Settings";
}

// MARK: - Device Delegate
- (void)initialDelegate {
    //self.presenter = [[SettingPresenter alloc] initWithDelegate:self];
	self.presenter = [SettingPresenter sharedInstance];
	[self.presenter setDelegate:self];
	
    self.presenter.navigationController = self.navigationController;
    self.tableView.delegate = self;
    self.tableView.dataSource = self;
}

// MARK: - TableView Delegate
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    NSArray<SymbolItemFromArray *> *settingLists =
    self.presenter.model.symbolTableFromArray;
    
    return settingLists.count > 0 ? settingLists.count : 0;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    SymbologyTableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"symbologyCell" forIndexPath:indexPath];
    
    SymbolItemFromArray *item = self.presenter.model.symbolTableFromArray[indexPath.row];
    cell.menuLabel.text = item.title;
    cell.switchOn.on = item.isOn;
    cell.switchOn.tag = indexPath.row;
    [cell.switchOn addTarget:self action:@selector(switchChanged:) forControlEvents:UIControlEventValueChanged];

    return cell;
}

// MARK: - TableView Delegate Methods
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
}

- (void)switchChanged:(UISwitch *)sender {
    NSInteger row = sender.tag;
    SymbolItemFromArray *item = self.presenter.model.symbolTableFromArray[row];
    [self.presenter.model toggleSymbolSwitch:item];
}

// MARK: - SettingPresenterDelegate
- (void)updatedReaderInfo {
    [self.tableView reloadData];
}

// MARK: - Button Actions
- (IBAction)btnEventAllEnable:(UIButton *)sender {
    [self.presenter setAllSymbolEnable];
    [self.tableView reloadData];
    [self.presenter updateSymbology];
}

- (IBAction)btnEventAllDisable:(UIButton *)sender {
    [self.presenter setAllSymbolDisable];
    [self.tableView reloadData];
    [self.presenter updateSymbology];
}

- (IBAction)btnUpdate:(UIButton *)sender {
    [self.presenter updateSymbology];
}

@end
