//
//  EPCData.h
//  AsReaderScan
//
//  Created by Mikiko on 11/7/24.
//  Copyright © 2024 SPS INC. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 *  @brief      This code defines two classes: EPCData and EPCHeader, which are used to handle EPC data, specifically for working with RFID tags in the GS1 EPC RFID format, such as SGTIN-96.
 */
@interface EPCData : NSObject
@property (nonatomic, strong)NSData *epcData;
@property (nonatomic, strong)NSString *hexEpcValue;
@property (nonatomic, assign)NSUInteger dataBits;
@property (nonatomic, assign)id header;

@property (nonatomic, strong)NSString *rfidProductCD;
@property (nonatomic, strong)NSString *epcPureURI;
@property (nonatomic, strong)NSString *epcTagURI;

@property (nonatomic, strong)NSString *barcodeType;
@property (nonatomic, strong)NSString *upcCD;

- (instancetype)initWithEpcData:(NSData *)epcData;

-(void)writeEPCData:(NSData*)epcData;
- (BOOL)setHexEpcValue:(NSString *)hexEpcValue dataLength:(NSUInteger)dataLength;
- (void)initData;
+(NSString *)getBinaryByhex:(NSString *)hex;
@end

@interface EPCHeader : NSObject
@property (nonatomic, strong)NSString *binaryHeaderValue;
@property (nonatomic, strong)NSString *hexHeaderValue;
@property (nonatomic, assign)long long encodingLength ;
@property (nonatomic, strong)NSString *codingScheme;

- (instancetype)initWithHexHeaderValue:(NSString *)hexHeaderValue;
@end
