//
//  ASXBaseModel.h
//  AsReaderScan
//
//  Created by Mikiko on 11/7/24.
//  Copyright © 2024 SPS INC. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 *  @brief      The ASXBaseModel.m file defines a model class ASXBaseModel, which is used to manage a data source.
 */
@interface ASXBaseModel : NSObject


@property(nonatomic,strong) NSArray *dataSource;

- (NSMutableArray*)proxyDatasource;

/**
 *  指定イニシャライザ1
 *
 *  @param dataSource NSMutableArray:データソース
 *
 *  @return id:SELFクラス
 */
- (id)initWithDatasource:(NSArray*)dataSource;

/**
 *  DataSourceのカウントを返す
 *
 *  @return NSUInteger:DataSourceのカウント
 */
- (NSUInteger)countOfDataSource;

/**
 *  指定したインデックスの要素を返す
 *
 *  @param index インデックス
 *
 *  @return 指定インデックスの要素
 */
- (id)objectInDataSourceAtIndex:(NSUInteger)index;

/**
 *  オブジェクトの追加
 *
 *  @param item id:追加オブジェクト
 */
- (void)addItem:(id)item;

/**
 *  オブジェクトの挿入
 *
 *  @param item  id:オブジェクト
 *  @param index index:挿入先の番号（配列の添字）
 */
- (void)insertItem:(id)item atIndex:(int)index;

/**
 *  オブジェクトの削除
 *
 *  @param index 削除先の番号（配列の添字）
 */
- (void)removeItemAtIndex:(int)index;

/**
 *  オブジェクトの入替え
 *
 *  @param fromIndex 入替え元の番号（配列の添字）
 *  @param toIndex   入替え後の番号（配列の添字）
 */
- (void)moveItemAtInex:(int)fromIndex toIndex:(int)toIndex;

@end
