//
//  ASXBaseModel.m
//  AsReaderScan
//
//  Created by Mikiko on 11/7/24.
//  Copyright © 2024 SPS INC. All rights reserved.
//

#import "ASXBaseModel.h"

@implementation ASXBaseModel

#pragma mark -- 指定イニシャライザ
/**
 *  イニシャライザ
 *
 *  @param dataSource NSMutableArray：データ配列
 *
 *  @return
 */
- (id)initWithDatasource:(NSMutableArray *)dataSource {
	self = [super init];
	if (self) {
		self.dataSource = dataSource;
	}
	return self;
}

- (id)init {
	return self = [self initWithDatasource:@[].mutableCopy];
}

#pragma mark -- NSArray
/**
 *  DataSourceのカウントを返す
 *
 *  @return NSUInteger:DataSourceのカウント
 */
- (NSUInteger)countOfDataSource {
	return _dataSource.count;
}

/**
 *  指定したインデックスの要素を返す
 *
 *  @param index インデックス
 *
 *  @return 指定インデックスの要素
 */
- (id)objectInDataSourceAtIndex:(NSUInteger)index {
	return _dataSource[index];
}

#pragma mark -- オブジェクト操作メソッド
- (NSMutableArray *)proxyDatasource {
	return [self mutableArrayValueForKey:NSStringFromSelector(@selector(dataSource))];
}

- (void)addItem:(id)item {
	if (!item) {
		return;
	}
	[self.proxyDatasource insertObject:item atIndex:self.countOfDataSource];
}

- (void)insertItem:(id)item atIndex:(int)index {
	if (!item) {
		return;
	}
    
	if (index < 0 || index > _dataSource.count) {
		return;
	}
	[self.proxyDatasource insertObject:item atIndex:index];
}

- (void)removeItemAtIndex:(int)index {
	if (index < 0 || index > _dataSource.count - 1) {
		return;
	}
	[self.proxyDatasource removeObjectAtIndex:index];
}

- (void)moveItemAtInex:(int)fromIndex toIndex:(int)toIndex {
	if (fromIndex < 0 || fromIndex > _dataSource.count - 1) {
		return;
	}
    
	if (toIndex < 0 || toIndex > _dataSource.count - 1) {
		return;
	}
    
	NSObject *item;
	item = _dataSource[fromIndex];
	[self.proxyDatasource removeObjectAtIndex:fromIndex];
	[self.proxyDatasource insertObject:item atIndex:toIndex];
}

@end
